# job-tailor


![Logo](https://github.com/sahilhadke/job-tailor/blob/main/jobtailor/resources/jobtailor-architecture.jpg)

"Job Tailor" is an efficient tool that transforms your master resume and a job description into a tailored resume and cover letter. It uses smart algorithms to highlight your most relevant skills, helping you stand out to potential employers. Save time and increase your chances of landing interviews with Job Tailor.

